@@ -66,11 +66,12 @@
   (list 10 4))
 
 (define (sequence-matches-slot? card-list slot)
-  (and (not (empty-slot? slot))
-       (= (get-suit (car card-list))
-	  (get-suit (get-top-card slot)))
-       (= (get-value (car card-list))
-	  (+ 1 (get-value (get-top-card slot))))))
+  (if (empty-slot? slot)
+      (= (get-value (car card-list)) ace)
+      (and (= (get-suit (car card-list))
+	      (get-suit (get-top-card slot)))
+           (= (get-value (car card-list))
+	      (+ 1 (get-value (get-top-card slot)))))))
 
 (define (button-pressed slot-id card-list)
   (and (not (empty-slot? slot-id))
@@ -99,9 +100,7 @@
 			  (get-suit (car card-list)))
 		       (= (get-value (get-top-card end-slot))
 			  (+ 1 (get-value (car (reverse card-list)))))))
-	      (or (> start-slot 7)
-		  (and (> start-slot 1)
-		       (< start-slot 6)))))
+              (< (length card-list) (+ 2 free-reserves))))
 	((and (> end-slot 1) ; The free reserves
 	      (< end-slot 6))
 	 (and (= (length card-list) 1)
@@ -119,7 +118,8 @@
   (cond ((= start-slot end-slot)
 	 #f)
 	((> end-slot 7)
-	 (and (or (and (empty-slot? end-slot)
+	 (and (< (length card-list) (+ 2 free-reserves))
+	      (or (and (empty-slot? end-slot)
 		       (= (get-value (car (reverse card-list)))
 			  king)
 		       (move-n-cards! start-slot end-slot card-list))
