@@ -32,6 +32,7 @@
 
 #ifdef HAVE_CLUTTER
 #include <clutter/clutter.h>
+#include <clutter-gtk/clutter-gtk.h>
 #endif
 
 #ifdef HAVE_HILDON
@@ -50,6 +51,7 @@
 #endif /* HAVE_HILDON */
 
 #if defined (G_OS_WIN32)
+#define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #include <io.h>
 #define HELP_EXT "xhtml"
@@ -71,10 +73,6 @@
 #include "util.h"
 #include "window.h"
 
-#ifdef HAVE_CLUTTER
-#include <libgames-support/games-clutter-embed.h>
-#endif
-
 typedef struct {
   AisleriotWindow *window;
   char *variation;
@@ -86,6 +84,8 @@ typedef struct {
 #endif /* HAVE_HILDON */
 } AppData;
 
+#if !GTK_CHECK_VERSION (2, 17, 0)
+
 static void
 about_url_hook (GtkAboutDialog *about,
                 const char *uri,
@@ -141,7 +141,12 @@ about_email_hook (GtkAboutDialog *about,
 {
   char *escaped, *uri;
 
+#if GLIB_CHECK_VERSION (2, 16, 0)
   escaped = g_uri_escape_string (email_address, NULL, FALSE);
+#else
+  /* Not really correct, but the best we can do */
+  escaped = g_strdup (email_address);
+#endif
   uri = g_strdup_printf ("mailto:%s", escaped);
   g_free (escaped);
 
@@ -149,6 +154,8 @@ about_email_hook (GtkAboutDialog *about,
   g_free (uri);
 }
 
+#endif /* GTK < 2.17.0 */
+
 static char *
 variation_to_game_file (const char *variation)
 {
@@ -498,7 +505,7 @@ main_prog (void *closure, int argc, char *argv[])
   osso_hw_state_t hw_events = {
     TRUE /* shutdown */,
     TRUE /* save unsaved data */,
-    FALSE /* low memory */,
+    TRUE /* low memory */,
     FALSE /* system inactivity */,
     OSSO_DEVMODE_NORMAL /* device mode */
     /* FIXMEchpe: or is OSSO_DEVMODE_INVALID the value to use
@@ -511,10 +518,6 @@ main_prog (void *closure, int argc, char *argv[])
 
 #ifdef HAVE_MAEMO
   /* Set OSSO callbacks */
-  /* NOTE: Passing the "org.gnome.games.aisleriot" service name to
-   * osso_initialize as first parameter to specify the full service name
-   * instead of getting com.nokia.* is undocumented.
-   */
   data.osso_context = osso_initialize (SERVICE_NAME, VERSION, FALSE, NULL);
   if (!data.osso_context) {
     g_print ("Failed to initialise osso\n");
@@ -541,7 +544,6 @@ main_prog (void *closure, int argc, char *argv[])
   add_main_options (option_context, &data);
 
   games_sound_enable (FALSE);
-  games_sound_add_option_group (option_context);
 
   g_option_context_add_group (option_context, gtk_get_option_group (TRUE));
 #ifdef WITH_SMCLIENT
@@ -561,7 +563,7 @@ main_prog (void *closure, int argc, char *argv[])
   }
 
 #ifdef HAVE_CLUTTER
-  if (games_clutter_init_with_args (NULL, NULL, NULL, NULL, NULL, &error) != CLUTTER_INIT_SUCCESS) {
+  if (gtk_clutter_init_with_args (NULL, NULL, NULL, NULL, NULL, &error) != CLUTTER_INIT_SUCCESS) {
     g_printerr ("Failed to initialise clutter: %s\n", error->message);
     g_error_free (error);
     goto cleanup;
@@ -602,8 +604,10 @@ main_prog (void *closure, int argc, char *argv[])
 
   aisleriot_util_set_help_func (help_hook, &data);
 
+#if !GTK_CHECK_VERSION (2, 17, 0)
   gtk_about_dialog_set_url_hook (about_url_hook, &data, NULL);
   gtk_about_dialog_set_email_hook (about_email_hook, &data, NULL);
+#endif
 
   data.window = AISLERIOT_WINDOW (aisleriot_window_new ());
   g_signal_connect (data.window, "destroy",
