@@ -36,13 +36,16 @@
 #else
 #include <hildon/hildon-banner.h>
 #endif
+#ifdef HAVE_MAEMO_5
+#include <hildon/hildon-gtk.h>
+#include <hildon/hildon-pannable-area.h>
+#endif
 #endif /* HAVE_HILDON */
 
 #include <libgames-support/games-card-theme.h>
 #include <libgames-support/games-card-themes.h>
 #include <libgames-support/games-clock.h>
 #include <libgames-support/games-debug.h>
-#include <libgames-support/games-files.h>
 #include <libgames-support/games-stock.h>
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-sound.h>
@@ -216,13 +219,12 @@ select_game_cb (GtkAction *action,
   GtkWidget *scrolled_window;
   GtkTreeViewColumn *column;
   GtkCellRenderer *renderer;
-  GamesFileList *files;
   GtkWidget *hbox;
   GtkTreeIter current_iter, selection_iter;
   gboolean current_iter_set = FALSE;
   const char *current_game_file;
   const char *games_dir;
-  GList *l;
+  GDir *dir;
 
   if (priv->game_choice_dialog) {
     gtk_window_present (GTK_WINDOW (priv->game_choice_dialog));
@@ -230,43 +232,50 @@ select_game_cb (GtkAction *action,
   }
 
   priv->game_choice_store = list = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
-  list_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list));
-  g_object_unref (list);
 
-  games_dir = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
-  files = games_file_list_new ("*.scm", games_dir, NULL);
-  games_file_list_transform_basename (files);
+#ifdef HAVE_MAEMO_5
+  list_view = hildon_gtk_tree_view_new_with_model (HILDON_UI_MODE_NORMAL, GTK_TREE_MODEL (list));
+#else
+  list_view = gtk_tree_view_new_with_model (GTK_TREE_MODEL (list));
+#endif
+  g_object_unref (list);
 
   current_game_file = aisleriot_game_get_game_file (priv->game);
 
-  for (l = files->list; l != NULL; l = l->next) {
-    const char *game_file = (const char *) l->data;
-    char *game_name;
-    GtkTreeIter iter;
+  games_dir = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
 
-    if (!game_file ||
-        strcmp (game_file, "sol.scm") == 0)
-      continue;
+  dir = g_dir_open (games_dir, 0, NULL);
+  if (dir != NULL) {
+    const char *game_file;
 
-    game_name = games_filename_to_display_name (game_file);
+    while ((game_file = g_dir_read_name (dir)) != NULL) {
+      char *game_name;
+      GtkTreeIter iter;
 
-    gtk_list_store_insert_with_values (GTK_LIST_STORE (list), &iter,
-                                       -1,
-                                       COL_NAME, game_name,
-                                       COL_GAME_FILE, game_file,
-                                       -1);
+      if (!g_str_has_suffix (game_file, ".scm") ||
+          strcmp (game_file, "sol.scm") == 0)
+        continue;
 
-    if (current_game_file &&
-        strcmp (current_game_file, game_file) == 0) {
-      current_iter = iter;
-      current_iter_set = TRUE;
+      game_name = games_filename_to_display_name (game_file);
+
+      gtk_list_store_insert_with_values (GTK_LIST_STORE (list), &iter,
+                                         -1,
+                                         COL_NAME, game_name,
+                                         COL_GAME_FILE, game_file,
+                                         -1);
+
+      if (current_game_file &&
+          strcmp (current_game_file, game_file) == 0) {
+        current_iter = iter;
+        current_iter_set = TRUE;
+      }
+
+      g_free (game_name);
     }
 
-    g_free (game_name);
+    g_dir_close (dir);
   }
 
-  g_object_unref (files);
-
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (list),
                                         0, GTK_SORT_ASCENDING);
 
@@ -307,11 +316,16 @@ select_game_cb (GtkAction *action,
   priv->game_choice_selection = selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list_view));
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
 
+#ifdef HAVE_MAEMO_5
+  scrolled_window = hildon_pannable_area_new ();
+#else
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window),
                                        GTK_SHADOW_IN);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
                                   GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+#endif /* HAVE_MAEMO_5 */
+
   gtk_container_add (GTK_CONTAINER (scrolled_window), list_view);
 
   gtk_box_pack_end (GTK_BOX (hbox), scrolled_window, TRUE, TRUE, 0);
@@ -785,8 +799,8 @@ debug_ensure_game_list (AisleriotWindow *window)
 {
   AisleriotWindowPrivate *priv = window->priv;
   DebugWindowData *data;
-  GamesFileList *files;
-  GList *l;
+  GDir *dir;
+  GList *list = NULL;
   const char *games_dir;
 
   data = g_object_get_data (G_OBJECT (window), DEBUG_WINDOW_DATA_KEY);
@@ -794,31 +808,29 @@ debug_ensure_game_list (AisleriotWindow *window)
     return data;
 
   games_dir = games_runtime_get_directory (GAMES_RUNTIME_GAME_GAMES_DIRECTORY);
-  files = games_file_list_new ("*.scm", games_dir, NULL);
-  games_file_list_transform_basename (files);
+  dir = g_dir_open (games_dir, 0, NULL);
+  if (dir != NULL) {
+    const char *game_file;
+
+    while ((game_file = g_dir_read_name (dir)) != NULL) {
+      if (!g_str_has_suffix (game_file, ".scm") ||
+          strcmp (game_file, "sol.scm") == 0)
+        continue;
+
+      list = g_list_prepend (list, g_strdup (game_file));
+    }
+
+    list = g_list_sort (list, (GCompareFunc) strcmp);
+    g_dir_close (dir);
+  }
 
   data = g_slice_new (DebugWindowData);
   data->window = window;
-  data->games_list = files->list;
+  data->games_list = list;
   data->current_game = g_list_find_custom (data->games_list,
                                            aisleriot_game_get_game_file (priv->game),
                                            (GCompareFunc) strcmp);
 
-  /* Remove the base sol.scm from the list */
-  for (l = data->games_list; l != NULL; l = l->next) {
-    char *game_file = (char *) l->data;
-
-    if (game_file != NULL &&
-        strcmp (game_file, "sol.scm") == 0) {
-      data->games_list = g_list_delete_link (data->games_list, l);
-      g_free (game_file);
-      break;
-    }
-  }
-
-  files->list = NULL;
-  g_object_unref (files);
-
   g_object_set_data_full (G_OBJECT (window), DEBUG_WINDOW_DATA_KEY,
                           data, (GDestroyNotify) debug_data_free);
 
@@ -1010,6 +1022,8 @@ toolbar_toggled_cb (GtkToggleAction *action,
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_TOOLBAR), state);
 }
 
+#ifndef HAVE_HILDON
+
 static void
 statusbar_toggled_cb (GtkToggleAction *action,
                       AisleriotWindow *window)
@@ -1026,6 +1040,8 @@ statusbar_toggled_cb (GtkToggleAction *action,
   games_conf_set_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_STATUSBAR), state);
 }
 
+#endif /* !HAVE_HILDON */
+
 static void
 set_fullscreen_actions (AisleriotWindow *window,
                         gboolean is_fullscreen)
@@ -1036,6 +1052,10 @@ set_fullscreen_actions (AisleriotWindow *window,
   g_object_set (priv->main_menu, "visible", !is_fullscreen, NULL);
 
   gtk_action_set_visible (priv->action[ACTION_LEAVE_FULLSCREEN], is_fullscreen);
+  g_object_set (gtk_ui_manager_get_widget (priv->ui_manager, "/Toolbar/LeaveFullscreenSep"),
+                "visible", is_fullscreen,
+                "draw", FALSE,
+                NULL);
 #endif
 
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (priv->action[ACTION_FULLSCREEN]),
@@ -1471,7 +1491,9 @@ aisleriot_window_take_card_theme (AisleriotWindow *window,
                                   GamesCardTheme *theme /* adopting */)
 {
   AisleriotWindowPrivate *priv = window->priv;
+#if GTK_CHECK_VERSION (2, 10, 0)
   GtkWidget *widget = GTK_WIDGET (window);
+#endif
 
   if (theme == priv->theme)
     return;
@@ -1481,12 +1503,14 @@ aisleriot_window_take_card_theme (AisleriotWindow *window,
   }
   priv->theme = theme;
 
+#if GTK_CHECK_VERSION (2, 10, 0)
   if (gtk_widget_has_screen (widget)) {
     const cairo_font_options_t *font_options;
 
     font_options = gdk_screen_get_font_options (gtk_widget_get_screen (widget));
     games_card_theme_set_font_options (theme, font_options);
   }
+#endif /* GTK+ 2.10.0 */
 
   aisleriot_board_set_card_theme (priv->board, theme);
 }    
@@ -1989,7 +2013,7 @@ game_exception_cb (AisleriotGame *game,
   gtk_widget_show (dialog);
 }
 
-#if defined(HAVE_CLUTTER) || defined(HAVE_CANBERRA_GTK)
+#if defined(HAVE_CLUTTER) || (defined(HAVE_CANBERRA_GTK) && GTK_CHECK_VERSION (2, 14, 0))
 
 static void
 settings_changed_cb (GtkSettings *settings,
@@ -2015,14 +2039,14 @@ settings_changed_cb (GtkSettings *settings,
   }
 #endif /* HAVE_CLUTTER */
 
-#ifdef HAVE_CANBERRA_GTK
+#if defined(HAVE_CANBERRA_GTK) && GTK_CHECK_VERSION (2, 14, 0)
   if (name == NULL || strcmp (name, "gtk-enable-event-sounds") == 0) {
     g_object_get (settings, "gtk-enable-event-sounds", &enabled, NULL);
 
     action = gtk_action_group_get_action (priv->action_group, "Sound");
     gtk_action_set_visible (action, enabled);
   }
-#endif /* HAVE_CANBERRA_GTK */
+#endif /* HAVE_CANBERRA_GTK && GTK >= 2.14 */
 }
 
 static void
@@ -2054,7 +2078,7 @@ screen_changed_cb (GtkWidget *widget,
   g_signal_connect (settings, "notify::gtk-enable-animations",
                     G_CALLBACK (settings_changed_cb), window);
 #endif
-#ifdef HAVE_CANBERRA_GTK
+#if defined (HAVE_CANBERRA_GTK) && GTK_CHECK_VERSION (2, 14, 0)
   g_signal_connect (settings, "notify::gtk-enable-event-sounds",
                     G_CALLBACK (settings_changed_cb), window);
 #endif
@@ -2263,19 +2287,23 @@ aisleriot_window_init (AisleriotWindow *window)
       G_CALLBACK (toolbar_toggled_cb),
       FALSE
     },
+#ifndef HAVE_HILDON
     { "Statusbar", NULL, N_("_Statusbar"), NULL,
       ACTION_TOOLTIP (N_("Show or hide statusbar")),
       G_CALLBACK (statusbar_toggled_cb),
       FALSE
     },
+#endif /* !HAVE_HILDON */
     { "ClickToMove", NULL, N_("_Click to Move"), NULL,
       ACTION_TOOLTIP (N_("Pick up and drop cards by clicking")),
       G_CALLBACK (clickmove_toggle_cb),
       FALSE /* not active by default */ },
+#ifdef ENABLE_SOUND
    { "Sound", NULL, N_("_Sound"), NULL,
       ACTION_TOOLTIP (N_("Whether or not to play event sounds")),
       G_CALLBACK (sound_toggle_cb),
       FALSE /* not active by default */ },
+#endif /* ENABLE_SOUND */
 #ifdef HAVE_CLUTTER
    { "Animations", NULL, N_("_Animations"), NULL,
       ACTION_TOOLTIP (N_("Whether or not to animate card moves")),
@@ -2332,6 +2360,9 @@ aisleriot_window_init (AisleriotWindow *window)
           "<menuitem action='Hint'/>"
           "<separator/>"
           "<menuitem action='ClickToMove'/>"
+#ifdef ENABLE_SOUND
+          "<menuitem action='Sound'/>"
+#endif
         "</menu>"
         "<menu action='OptionsMenu'/>"
         "<menu action='HelpMenu'>"
@@ -2379,7 +2410,9 @@ aisleriot_window_init (AisleriotWindow *window)
           "<menuitem action='Hint'/>"
           "<separator/>"
           "<menuitem action='ClickToMove'/>"
+#ifdef ENABLE_SOUND
           "<menuitem action='Sound'/>"
+#endif
 #ifdef HAVE_CLUTTER
           "<menuitem action='Animations'/>"
 #endif
@@ -2419,6 +2452,7 @@ aisleriot_window_init (AisleriotWindow *window)
         "<toolitem action='Deal'/>"
         "<toolitem action='Hint'/>"
 #ifndef HAVE_MAEMO
+        "<separator name='LeaveFullscreenSep' expand='true'/>"
         "<toolitem action='LeaveFullscreen'/>"
 #endif
 #ifdef ENABLE_DEBUG_UI
@@ -2636,19 +2670,26 @@ aisleriot_window_init (AisleriotWindow *window)
   priv->toolbar_visible = games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_TOOLBAR), NULL) != FALSE;
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                 priv->toolbar_visible);
-  action = gtk_action_group_get_action (priv->action_group, "Statusbar");
-  priv->statusbar_visible = games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_STATUSBAR), NULL) != FALSE;
-  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
-                                priv->statusbar_visible);
   action = gtk_action_group_get_action (priv->action_group, "ClickToMove");
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                 games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_CLICK_TO_MOVE), NULL));
+
+  action = gtk_action_group_get_action (priv->action_group, "RecentMenu");
+  g_object_set (action, "hide-if-empty", FALSE, NULL);
+
+#ifdef ENABLE_SOUND
   action = gtk_action_group_get_action (priv->action_group, "Sound");
   gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                 games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_SOUND), NULL));
   gtk_action_set_visible (action, games_sound_is_available ());
-  action = gtk_action_group_get_action (priv->action_group, "RecentMenu");
-  g_object_set (action, "hide-if-empty", FALSE, NULL);
+#endif /* ENABLE_SOUND */
+
+#ifndef HAVE_HILDON
+  action = gtk_action_group_get_action (priv->action_group, "Statusbar");
+  priv->statusbar_visible = games_conf_get_boolean (NULL, aisleriot_conf_get_key (CONF_SHOW_STATUSBAR), NULL) != FALSE;
+  gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
+                                priv->statusbar_visible);
+#endif /* !HAVE_HILDON */
 
 #ifdef ENABLE_CARD_THEMES_INSTALLER
   action = gtk_action_group_get_action (priv->action_group, "InstallThemes");
@@ -2664,7 +2705,7 @@ aisleriot_window_init (AisleriotWindow *window)
 
 #endif /* HAVE_CLUTTER */
 
-#if defined(HAVE_CLUTTER) || defined(HAVE_CANBERRA_GTK)
+#if defined(HAVE_CLUTTER) || (defined(HAVE_CANBERRA_GTK) && GTK_CHECK_VERSION (2, 14, 0))
   /* Set the action visibility and listen for animation and sound mode changes */
   screen_changed_cb (GTK_WIDGET (window), NULL, window);
   g_signal_connect (window, "screen-changed",
