@@ -33,7 +33,6 @@
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-scores.h>
 #include <libgames-support/games-scores-dialog.h>
-#include <libgames-support/games-sound.h>
 #include <libgames-support/games-stock.h>
 
 #ifdef WITH_SMCLIENT
@@ -226,7 +225,6 @@ main (int argc, char *argv[])
 #endif /* WITH_SMCLIENT */
 
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
-  games_sound_add_option_group (context);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
   g_option_context_free (context);
