@@ -164,8 +164,7 @@ games_sound_init (void)
 /* Sounds don't sound good on Windows unless the buffer size is 4k,
  * but this seems to cause strange behaviour on other systems,
  * such as a delay before playing the sound. */
-#ifdef WIN32_NATIVE
-#define BUF_SIZE (4096)
+#ifdef G_OS_WIN32
   const size_t buf_size = 4096;
 #else
   const size_t buf_size = 1024;
